#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-client
version:              0.0.3
visibility:           public
id:                   casa-client-0.0.3-9J0jnrjd5CE4uDITWWwOjx
key:                  casa-client-0.0.3-9J0jnrjd5CE4uDITWWwOjx
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Client for Casa
description:
    Client for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  fefdebfc8dfca916df1667b37248d5cf
exposed:              True
exposed-modules:      Casa.Client
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-client
hs-libraries:         HScasa-client-0.0.3-9J0jnrjd5CE4uDITWWwOjx
depends:
    aeson-2.2.2.0-CRLoVrOByflKEQQ5tNkVEn
    attoparsec-0.14.4-HFulVz6SrFwG1FlMeqAukh base-4.18.2.1
    base16-bytestring-1.0.2.0-AMtBRFHYCKP9ubQlj6HdMp
    bytestring-0.11.5.3 casa-types-0.0.3-H9gkZvp0GgvKQFQgmto60H
    conduit-1.3.6.1-3ZkfU3UFxE9HTVkK8cD
    conduit-extra-1.3.8-CBry4ZxjfNzDWNilco7aIQ
    crypton-1.0.4-5fA2jRD5YCU8JiTQyX4nZ5 exceptions-0.10.7
    http-conduit-2.3.9.1-FDcTCktOtYxKu3CCbOTyb9
    http-types-0.12.4-DWpoveyaOeC1PmowHzh97w
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-uri-2.6.4.2-DZsK30J0JA75RbwwKgdhQI
    resourcet-1.2.6-ISzbKkOS7tA59m6DqAPsM template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-170HxTRPWLJC6Js92iIt2k

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

